Logical Graph Editor
Description: Interactive flowchart diagram implemented by GoJS in JavaScript for HTML.

Palette

- Graph
- JSON
- PNG
- Translate

| Translate the Logical Graph to either Physical Graph Template (PGT) or Physical Graph Template Partition (PGTP)
Unroll |
| Minimise data movement and balance loads given the number of nodes
# of nodes |
Node label |
Load balancing | %
| Minimise execution time and resources given node capacities
Node label |
CPUs per node |
Memory per node | Megabytes

Logical Graphs

Mouse-over a Node to view its ports. Drag from these ports to create new Links. Selecting a Node and then clicking its TextBlock will allow you to edit text (except on the Start and End Nodes).
Any issues please email chen DOT wu AT icrar DOT org